@@ -621,8 +621,8 @@ class RabbitMQStreamsProtocol(asyncio.Protocol):
         :param subscription_id: RabbitMQ stream subscription id.
         :param queue: Message queue for a RabbitMQ stream.
         """
-        credit = queue.inc_credit()
-        self.send_credit(subscription_id, credit)
+        credit_delta = queue.inc_credit()
+        self.send_credit(subscription_id, credit_delta)
 
     def data_received(self, chunk: bytes) -> None:
         self._timestamp = self._loop.time()
